diff mbox series

[net-next,1/7] netfilter: nftables: rename set element data activation/deactivation functions

Message ID 20210427204345.22043-2-pablo@netfilter.org
State Accepted
Delegated to: Pablo Neira
Headers show
Series [net-next,1/7] netfilter: nftables: rename set element data activation/deactivation functions | expand

Commit Message

Pablo Neira Ayuso April 27, 2021, 8:43 p.m. UTC
Rename:

- nft_set_elem_activate() to nft_set_elem_data_activate().
- nft_set_elem_deactivate() to nft_set_elem_data_deactivate().

To prepare for updates in the set element infrastructure to add support
for the special catch-all element.

Signed-off-by: Pablo Neira Ayuso <pablo@netfilter.org>
---
 net/netfilter/nf_tables_api.c | 22 +++++++++++-----------
 1 file changed, 11 insertions(+), 11 deletions(-)

Comments

patchwork-bot+netdevbpf@kernel.org April 27, 2021, 10:40 p.m. UTC | #1
Hello:

This series was applied to netdev/net-next.git (refs/heads/master):

On Tue, 27 Apr 2021 22:43:39 +0200 you wrote:
> Rename:
> 
> - nft_set_elem_activate() to nft_set_elem_data_activate().
> - nft_set_elem_deactivate() to nft_set_elem_data_deactivate().
> 
> To prepare for updates in the set element infrastructure to add support
> for the special catch-all element.
> 
> [...]

Here is the summary with links:
  - [net-next,1/7] netfilter: nftables: rename set element data activation/deactivation functions
    https://git.kernel.org/netdev/net-next/c/f8bb7889af58
  - [net-next,2/7] netfilter: nftables: add loop check helper function
    https://git.kernel.org/netdev/net-next/c/6387aa6e59be
  - [net-next,3/7] netfilter: nftables: add helper function to flush set elements
    https://git.kernel.org/netdev/net-next/c/e6ba7cb63b8a
  - [net-next,4/7] netfilter: nftables: add helper function to validate set element data
    https://git.kernel.org/netdev/net-next/c/97c976d662fb
  - [net-next,5/7] netfilter: nftables: add catch-all set element support
    https://git.kernel.org/netdev/net-next/c/aaa31047a6d2
  - [net-next,6/7] netfilter: nft_socket: fix an unused variable warning
    https://git.kernel.org/netdev/net-next/c/8a7363f84979
  - [net-next,7/7] netfilter: nft_socket: fix build with CONFIG_SOCK_CGROUP_DATA=n
    https://git.kernel.org/netdev/net-next/c/7acc0bb490c8

You are awesome, thank you!
--
Deet-doot-dot, I am a bot.
https://korg.docs.kernel.org/patchwork/pwbot.html
diff mbox series

Patch

diff --git a/net/netfilter/nf_tables_api.c b/net/netfilter/nf_tables_api.c
index 1050f23c0d29..d66be7d8f3e5 100644
--- a/net/netfilter/nf_tables_api.c
+++ b/net/netfilter/nf_tables_api.c
@@ -5263,8 +5263,8 @@  void nft_set_elem_destroy(const struct nft_set *set, void *elem,
 }
 EXPORT_SYMBOL_GPL(nft_set_elem_destroy);
 
 /* Only called from commit path, nft_set_elem_deactivate() already deals with
  * the refcounting from the preparation phase.
  */
 static void nf_tables_set_elem_destroy(const struct nft_ctx *ctx,
 				       const struct nft_set *set, void *elem)
@@ -5733,9 +5733,9 @@  void nft_data_hold(const struct nft_data *data, enum nft_data_types type)
 	}
 }
 
-static void nft_set_elem_activate(const struct net *net,
-				  const struct nft_set *set,
-				  struct nft_set_elem *elem)
+static void nft_setelem_data_activate(const struct net *net,
+				      const struct nft_set *set,
+				      struct nft_set_elem *elem)
 {
 	const struct nft_set_ext *ext = nft_set_elem_ext(set, elem->priv);
 
@@ -5745,9 +5745,9 @@  static void nft_set_elem_activate(const struct net *net,
 		(*nft_set_ext_obj(ext))->use++;
 }
 
-static void nft_set_elem_deactivate(const struct net *net,
-				    const struct nft_set *set,
-				    struct nft_set_elem *elem)
+static void nft_setelem_data_deactivate(const struct net *net,
+					const struct nft_set *set,
+					struct nft_set_elem *elem)
 {
 	const struct nft_set_ext *ext = nft_set_elem_ext(set, elem->priv);
 
@@ -5824,7 +5824,7 @@  static int nft_del_setelem(struct nft_ctx *ctx, struct nft_set *set,
 	kfree(elem.priv);
 	elem.priv = priv;
 
-	nft_set_elem_deactivate(ctx->net, set, &elem);
+	nft_setelem_data_deactivate(ctx->net, set, &elem);
 
 	nft_trans_elem(trans) = elem;
 	nft_trans_commit_list_add_tail(ctx->net, trans);
@@ -5858,7 +5858,7 @@  static int nft_flush_set(const struct nft_ctx *ctx,
 	}
 	set->ndeact++;
 
-	nft_set_elem_deactivate(ctx->net, set, elem);
+	nft_setelem_data_deactivate(ctx->net, set, elem);
 	nft_trans_elem_set(trans) = set;
 	nft_trans_elem(trans) = *elem;
 	nft_trans_commit_list_add_tail(ctx->net, trans);
@@ -8479,7 +8479,7 @@  static int __nf_tables_abort(struct net *net, enum nfnl_abort_action action)
 		case NFT_MSG_DELSETELEM:
 			te = (struct nft_trans_elem *)trans->data;
 
-			nft_set_elem_activate(net, te->set, &te->elem);
+			nft_setelem_data_activate(net, te->set, &te->elem);
 			te->set->ops->activate(net, te->set, &te->elem);
 			te->set->ndeact--;
@@ -5263,8 +5263,8 @@  void nft_set_elem_destroy(const struct nft_set *set, void *elem,
 EXPORT_SYMBOL_GPL(nft_set_elem_destroy);
 
-/* Only called from commit path, nft_set_elem_deactivate() already deals with
- * the refcounting from the preparation phase.
+/* Only called from commit path, nft_setelem_data_deactivate() already deals
+ * with the refcounting from the preparation phase.
  */
 static void nf_tables_set_elem_destroy(const struct nft_ctx *ctx,